gis_csdt
========
[![Build Status](https://travis-ci.org/CSDTs/SGIS-backend.svg?branch=master)](https://travis-ci.org/CSDTs/SGIS-backend)[![Coverage Status](https://coveralls.io/repos/github/CSDTs/SGIS-backend/badge.svg?branch=master)](https://coveralls.io/github/CSDTs/SGIS-backend?branch=master) [![Updates](https://pyup.io/repos/github/CSDTs/SGIS-backend/shield.svg)](https://pyup.io/repos/github/CSDTs/SGIS-backend/)

The API backend of SGIS for the 3Helix program.

The frontend can be found [here](https://github.com/gouravjeet/SGIS-2.0).

##Contents
* [Fall 2014 Independent Study Syllabus](doc/syllabus.md)
* [Installation](doc/installation.md)
* [API Usage](doc/usage.md)
* [Adding a Dataset](doc/new-dataset.md)
